//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Tile](../index.md)/[Companion](index.md)/[allExcludeAkaDora](all-exclude-aka-dora.md)

# allExcludeAkaDora

[common]\
val [allExcludeAkaDora](all-exclude-aka-dora.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../index.md)&gt;

所有牌
